from setuptools import setup
setup(
    name="uule_grabber",
    packages=["uule_grabber"],
    version="0.1",
    description="Generates UULE codes for Google Search ",
    author="Kemal Ogun Isik",
    author_email="ogunisik@gmail.com",
    url="https://github.com/ogun/uule_grabber",
    download_url="https://github.com/ogun/uule_grabber/archive/0.1.tar.gz",
    classifiers=[],
)
